@@ -16,6 +16,7 @@ def main():
 
     commands = parser.add_subparsers(dest='command')
     auth_parser = commands.add_parser('auth', help='Authentication')
+    rewards_parser = commands.add_parser('rewards', 'Reward management')
 
 
     # |-----------------
@@ -39,6 +40,15 @@ def main():
     auth_parser.add_argument('-S', dest='scope', nargs='+')
 
 
+    # |--------------------
+    # | Reward management
+    
+    from . import client_id
+
+    rewards_action = rewards_parser.add_mutually_exclusive_group(required=True)
+    rewards_action.add_argument('add')
+
+
     args = parser.parse_args()
 
     if args.command == 'auth':
